@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Channel.tcl,v $
-# $Date: 1998/04/27 11:45:55 $
-# $Revision: 1.18.1.147 $
+# $Date: 1998/06/05 19:34:07 $
+# $Revision: 1.18.1.159 $
 #
 #
 package provide zircon 1.18
@@ -17,6 +17,7 @@ proc nil {op args} {
     isa { return 0 }
     opText -
     addText {global currentNet ; eval [$currentNet info] addText $args}
+    osTag { return [lindex $args 1] }
     default { error "***** \007\007 nil called : $op $args" }
     }	
 }
@@ -49,7 +50,7 @@ proc oneLiner {win chid} {
     set x [split [$win get]]
     if {![string match {} [set who [lindex $x 0]]] &&
       ![string match {} [set msg [join [lrange $x 1 end]]]]} {
-	$net qSend PRIVMSG $who :$msg
+	$net q1Send "PRIVMSG $who :$msg"
 	$chid addText {} ">>$who : $msg"
     }
     $win delete 0 end
@@ -68,23 +69,17 @@ proc setClose {this val} {
     if {[regexp {^[0-9]+$} $val]} { $this configure -closetime $val }
 }
 #
-proc clearClose {this args} {
-    upvar #0 $this cdata
-    set cdata(close) 0
-}
+proc clearClose {this args} { uplevel #0 set ${this}(close) 0 }
 #
 proc channel_set {this flag} {
-    switch $flag {
-    close {
-	    if {[$this close]} {
-		switch 0 [set v [$this closetime]] {set v {}}
-		tkwait window [mkEntryBox .@cl$this {Close Time} \
-		  "Enter the close time for [$this name]:" \
-		  [list [list Time $v]] [list ok "setClose $this"] \
-		  [list cancel "clearClose $this"]]
-	    }
+    switch $flag close {
+	if {[$this close]} {
+	    switch 0 [set v [$this closetime]] {set v {}}
+	    tkwait window [mkEntryBox .@cl$this {Close Time} \
+	      "Enter the close time for [$this name]:" \
+	      [list [list Time $v]] [list ok "setClose $this"] \
+	      [list cancel "clearClose $this"]]
 	}
-    nocase {}
     }
 }
 #
@@ -128,20 +123,11 @@ proc makeChannel {chan} {
 proc channel_onShow {this} {
     if {[$this active]} { $this setTopic {} }
     switch -glob -- [$this name] +* {} default {
-	[$this net] qSend MODE :[$this name]
+	[$this net] q1Send "MODE :[$this name]"
 	$this configure -modewait 1
     }
 }
 #
-proc channel_defaultTags {this} {
-    global TFn TFg TBg BF
-    set txt [$this text]
-    foreach x {@BAN @CTCP @ERROR @INFO @QUIT @WARN} {
-	setTags $this $x
-	confTag $txt $x $TFg($this,$x) $TBg($this,$x) $TFn($this,$x) $BF($this)
-    }
-}
-#
 proc channel_show {this args} {
     if {[$this active]} {
 	$this flag normal
@@ -243,87 +229,6 @@ proc channel_addText {this tag text} {
     $this doAddText $tag $text
 }
 #
-proc getOValue {this win opt lc uc} {
-    upvar #0 $this cdata
-    if {[info exists cdata($lc)]} {
-	switch {} $cdata($lc) {} default { return $cdata($lc) }
-    }
-    switch {} [set x [option get $win $lc $uc]] {set x [$win cget -$opt]}
-    return $x
-}
-#
-proc getTValue {this win win2 opt lc uc} {
-    switch {} [set x [option get $win $lc $uc]] {
-	upvar #0 $this cdata
-    	if {[info exists $cdata($opt)]} {
-	    switch {} $cdata($opt) {} default { return $cdata($opt) }
-	}
-	if {[catch {$win2 cget -$opt} x]} {
-	    error "Weird error!!!! ($x) - please tell \
-zircon@catless.ncl.ac.uk exactly what you were doing when this happened."
-	} 
-    }
-    return $x
-}
-#
-proc setTags {this nk} {
-    global TFn TFa TFg TBg TAF TAB TBl Bl
-    set w [$this text]
-    set x "$this,$nk"
-    set ch [$this tagWindow]
-    set TFn($x) [getTValue $this $ch $w font ${nk}Font Font]
-    set TFg($x) [getTValue $this $ch $w foreground ${nk}Foreground Foreground]
-    set TBg($x) [getTValue $this $ch $w background ${nk}Background Background]
-    set TFa($x) [getTValue $this $ch $w font ${nk}ActionFont Font]
-    set TAF($x) [getTValue $this $ch $w foreground ${nk}ActionForeground Foreground]
-    set TAB($x) [getTValue $this $ch $w background ${nk}ActionBackground Background]
-    switch {} [set TBl($x) [option get $ch ${nk}Bell Bell]] {
-	if {[info exists Bl($this)]} { set TBl($x) $Bl($this) }
-    }
-}
-#
-proc tagConf {txt tag fg bg ft} {
-    catch {$txt tag configure $tag -foreground $fg}
-    catch {$txt tag configure $tag -background $bg}
-    switch {} $ft {} default {catch {$txt tag configure $tag -font $ft}}
-}
-#
-proc confTag {txt tag fg bg font bold} {
-    switch {} $tag {} default {tagConf $txt $tag $fg $bg $font}
-    tagConf $txt @b@$tag $fg $bg $bold
-    tagConf $txt @v@$tag $bg $fg {}
-    tagConf $txt @u@$tag $fg $bg {}
-    $txt tag configure @u@$tag -underline 1
-    tagConf $txt @a@$tag $bg $fg {}
-    $txt tag configure @a@$tag -relief raised -borderwidth 2
-}
-#
-proc channel_makeTag {this usr} {
-    global Fg Bg BF
-    if {[[$this net] me $usr]} {
-	set tagInfo [$this tagInfo [set tag @me]]
-    } {
-	set tagInfo [$this tagInfo [[set tag $usr] lname]]
-    }
-    set name [$this text]
-    confTag $name $tag [lindex $tagInfo 0] [lindex $tagInfo 1] \
-       [lindex $tagInfo 2] [expr {[string match {} $BF($this)] ? $font : $BF($this)}]
-}
-#
-proc channel_delTag {this usr} {
-    global TFn TFa TFg TBg TAF TAB TBl
-    if {[[$this net] me $usr]} { set tag @me } { set tag [$usr lname] }
-    foreach x {TFn TFa TFg TBg TAF TAB TBl} { catch {unset ${x}($this,$tag)} }
-}
-#
-proc channel_tagInfo {this tag} {
-    switch -- $tag {} {return {}}
-    global TFn TFg TBg
-    set indx "$this,$tag"
-    if {![info exists TFn($indx)]} { setTags $this $tag }
-    return [list $TFg($indx) $TBg($indx) $TFn($indx)]
-}
-#
 proc channel_send {this string args} {
     switch {} $string {} default {
 	global Secure
@@ -333,9 +238,9 @@ proc channel_send {this string args} {
 	  {[info exists Secure($lc)] ? $Secure($lc) : [$this name]}]
 	set net [$this net]
 	switch {} [set key [$this crypt]] {
-	    $net qSend PRIVMSG $rchan :$string
+	    $net q1Send "PRIVMSG $rchan :$string"
 	} default {
-	    $net qSend PRIVMSG $rchan :[encrypt $string $key]
+	    $net q1Send "PRIVMSG $rchan :[encrypt $string $key]"
 	}
 	regsub -all %n [$this mytag] [[$net myid] name] pr
 	switch -- $args {} {
@@ -391,11 +296,11 @@ proc channel_doNames {this param} {
     upvar #0 $this cdata
     switch {} $cdata(mwin) {} default {
 # We are monitoring this channel.
-        $cdata(mwin) update $param
+	$cdata(mwin) update $param
 	return
     }
     if {![$this active]} {
-        mkInfoBox $cdata(net) NAMES .@names$this [list names $cdata(name)] $param
+	mkInfoBox $cdata(net) NAMES .@names$this [list names $cdata(name)] $param
 	return
     }
     set kids $cdata(users)
@@ -444,7 +349,7 @@ proc channel_sendJoin {this args} {
 #
 proc channel_putJoin {this key} {   
     switch {} $key {} default { $this configure -key $key }
-    [$this net] qSend JOIN [$this name] :[$this key]
+    [$this net] q1Send "JOIN [$this name] :[$this key]"
     upvar #0 $this cdata
     array set cdata {p 0 lclp 0 m 0 lclm 0 s 0 lcls 0 i 0 \
       lcli 0 t 0 lclt 0 n 0 lcln 0 a 0 lcla 0 }
@@ -481,15 +386,17 @@ proc channel_doJoin {this usr nm prefix ov} {
 	catch {$cdata(ufrm).userBtn.$usr conf -state normal}
 	listkill cdata(splitusers) $usr
 	$usr heal
-	[$this net] qSend NAMES :[$this name]
+#	[$this net] q1Send "NAMES :[$this name]"
+	$this optText BACK \
+	  "*** [$usr name] ($nm) is back"
     }
     $this handleOV $ov $usr
     $this setOps $prefix $usr
     foreach x [$this ban] {
 	if {[regexp -nocase [lindex $x 0] $prefix]} {
 	    set net [$this net]
-	    $net qSend MODE [$this name] +b [lindex $x 1]
-	    $net qSend KICK [$this name] [$usr name] ":Ban List for [$this name]"
+	    $net q1Send "MODE [$this name] +b [lindex $x 1]"
+	    $net q1Send "KICK [$this name] [$usr name] :Ban List for [$this name]"
 	    break
 	}
     }
@@ -527,19 +434,19 @@ proc setOption {this sub opt val} {
 #
 proc channel_control {this args} { return [[$this net] control] }
 #
-array set TypeCode {
-    Channel	text
-    Message	msg
-    Notice	note
-    Chat	chat
-    Info	info
-}
-#
 proc channel_configure {this args} {
     upvar #0 $this cdata
     foreach {name val} $args {
 	set opt [string range $name 1 end]
 	switch -glob -- $name {
+	-history {
+	    switch {} $val { set val 50 }
+	    set cdata(history) $val
+	}
+	-scrollback {
+	    switch {} $val { set val 0 }
+	    set cdata(scrollback) $val
+	}
 	-ban {
 		set cdata(ban) {}
 		foreach x $val {
@@ -610,7 +517,7 @@ for regular expression \"$v\" in -ban for channel [$this name]"
 		set cdata(buttons) $val
 		if {[winfo exists $cdata(window).users.menu]} {
 		    $cdata(window).users.menu entryconfigure 0 -label \
-		      [expr {[$this buttons] ? {No Buttons} : {Buttons}}]
+		      [trans [expr {[$this buttons] ? {no buttons} : {buttons}}]]
 		}
 	    }
 	-name {
@@ -637,7 +544,7 @@ for regular expression \"$v\" in -ban for channel [$this name]"
 	-monitor {
 		if {!$val} {
 		    switch {} $cdata(mwin) {} default {
-		        $cdata(mwin) delete
+			$cdata(mwin) delete
 			set cdata(mwin) {}
 		    }
 		    [$this net] deMonitor $this
@@ -652,6 +559,8 @@ for regular expression \"$v\" in -ban for channel [$this name]"
 	-joinat {
 		checkJoinTime $this $val
 	    }
+	-msg { set cdata(msg) [string toupper $val] }
+	+msg { lappend cdata(msg) [string toupper $val] }
 	+*  { lappend cdata($opt) $val }
 	-*  { set cdata($opt) $val }
 	}
@@ -675,29 +584,6 @@ proc channel_popdown {this} {
     }
 }
 #
-proc cmkw {path} {
-    if {![winfo exists $path] && [catch {frame $path} msg]} {
-	tellError {} {Option Host Error} "Error in your X resources - $msg"
-	return 1
-    }
-    return 0
-}
-#
-proc channel_tagWindow {this} {
-   set w [$this lname]
-   set type [string tolower [$this type]]
-   if {![winfo exists .$type.$w]} {
-	if {[cmkw [set path .$type]]} { return . }
-	set r $w
-	while {[regexp {([^.]*)\.(.*)} $r match f r]} {	
-	    append path .$f
-	    if {[cmkw $path]} { return .$type }
-	}
-	if {[cmkw $path.$r]} { return .$type }
-   }
-   return .$type.$w
-}
-#
 proc channel_setTitles {this} {
    $this configure -mwin {}
    return [list [$this name] [$this name]]
@@ -746,18 +632,12 @@ proc makeCTopic {this net w chan rchan idx cdx look} {
     bind $w.topic.entry <ButtonPress-3> "notIdle %W $net ; $this popPalette Topic %X %Y"
     $w.topic.entry configure -state disabled -width 0
     grid $w.topic.label -column 0 -row 0
+    setProps $this $w.topic.entry
     grid $w.topic.entry -column 1 -row 0 -sticky ew
     bind $w.topic.entry <Return> "sendTopic $this %W ; notIdle %W $net"
     grid $w.topic -sticky ew -column $cdx -row 0 -in $w.r$idx
 }
 #
-proc setProps {chan win} {
-    foreach x {font background foreground} {
-        switch {} [set v [$chan $x]] continue
-	$win configure -$x $v
-    }
-}
-#
 proc makeCText {this net w chan rchan idx cdx look} {
     global zLock zUnlock TypeCode
     set f [frame $w.r$idx.textFrm -borderwidth 0]
@@ -882,20 +762,14 @@ proc channel_toggle {this val win} {
     $this configure -$val $flg
     $win configure -image $im
 }
-
-#
-proc channel_heal {this usr} {
-    switch {} [$this mwin] return
-    [$this mwin] setState $usr normal
-}
 #
 proc channel_remove {this usr} {
     if {[$this isJoined $usr] &&
       ![normal [$this ufrm].userBtn.$usr]} {
-        $this killUser $usr
+	$this killUser $usr
     } elseif {[$this monitor]} {
-        switch {} [$this mwin] {} default {
-            [$this mwin] remove $usr
+	switch {} [$this mwin] {} default {
+	    [$this mwin] remove $usr
 	}
     }
 }
@@ -924,9 +798,9 @@ proc makeCtlMode {this net w chan rchan idx look} {
     upvar #0 $this cdata
     set om [makeMB $w.mode Mode]
     addImage $w.mode mode $w.cmds $idx $net
-    $om add checkbutton -label {Pop Up} -variable ${this}(open) \
+    $om add checkbutton -label [trans {pop up}] -variable ${this}(open) \
 	-command "$this set open"
-    $om add checkbutton -label {Pop Down} -variable ${this}(close) \
+    $om add checkbutton -label [trans {pop down}] -variable ${this}(close) \
 	-command "$this set close"
     $om add checkbutton -label [trans draw] -variable ${this}(draw) \
       -command "$this drawSet"
@@ -936,7 +810,7 @@ proc makeCtlMode {this net w chan rchan idx look} {
     $om add checkbutton -label [trans actions] -variable ${this}(actions) \
       -command "$this flipActions"
     if {$cdata(timestamp)} {
-	$om add checkbutton -label Timestamp -variable ${this}(stampMsg)
+	$om add checkbutton -label [trans timestamp] -variable ${this}(stampMsg)
 	set cdata(stampMsg) 1
     }
     if {[$this isa Channel]} {
@@ -947,13 +821,13 @@ proc makeCtlMode {this net w chan rchan idx look} {
 	    $om add command -command "$this setBan" -label [trans ban]
 	    foreach {v tx} "p private m moderated \
 	      s secret i {Invite Only} t topic n {No Msg}" {
-	        uplevel #0 trace variable ${this}($v) w "{updVar $this}"
+		uplevel #0 trace variable ${this}($v) w "{updVar $this}"
 		set cdata($v) 0
 		$om add checkbutton -command "$this changeMode $v" \
 		  -variable ${this}(lcl$v) -state disabled -label [trans $tx]
 	    }
 	    if {$efs29 && [string match {&*} $rchan]} {
-	        uplevel #0 trace variable ${this}(a) w "{updVar $this}"
+		uplevel #0 trace variable ${this}(a) w "{updVar $this}"
 		set cdata(a) 0
 		$om add checkbutton -command "$this changeMode a" \
 		  -variable ${this}(lcla) -state disabled -label [trans anonymous]
@@ -968,7 +842,7 @@ proc makeCtlInfo {this net w chan rchan idx look} {
     if {[$this isa Channel]} {
 	set om [makeMB $w.channel Channel]
 	addImage $w.channel channel $w.cmds $idx $net
-	$om add command -command "$net qSend WHO {:$rchan}" -label [trans who]
+	$om add command -command "$net q1Send {WHO :$rchan}" -label [trans who]
 	$om add command -command "userInvite $net {$chan}" -label [trans invite]
 	$om add command -command "channelNotice $net {$chan}" -label [trans notice]
 	$om add cascade -label [trans messages] -menu $om.msgs
@@ -1158,8 +1032,8 @@ proc channel_keepMsg {this str} {
 #
 proc lclTrace {chan var} {
     switch {} [uplevel #0 trace vinfo ${chan}($var)] {
-        uplevel #0 trace variable ${chan}($var) w "{updVar $chan}"
-        uplevel #0 trace variable ${chan}($var) u "{unsVar $chan}"
+	uplevel #0 trace variable ${chan}($var) w "{updVar $chan}"
+	uplevel #0 trace variable ${chan}($var) u "{unsVar $chan}"
     }
 }
 #
@@ -1177,7 +1051,7 @@ proc channel_buildUsersMenu {this w} {
     set cdata(Op,$myid) 0
     lclTrace $this Spk,$myid
     set cdata(Spk,$myid) 0
-    $w add command -label [expr {[$this buttons] ? {No Buttons} : {Buttons}}] \
+    $w add command -label [trans [expr {[$this buttons] ? {no buttons} : {buttons}}]] \
       -command "$this toggleUsers"
     $w add separator
 }
@@ -1205,7 +1079,7 @@ proc channel_toggleUsers {this} {
 	$w.users.menu entryconfigure 1 -label [trans buttons]
     } {	
 	eval grid $f [$this anonpos]
-	$w.users.menu entryconfigure 1 -label {No Buttons}
+	$w.users.menu entryconfigure 1 -label [trans {no buttons}]
     }
 }
 #
@@ -1216,7 +1090,7 @@ proc mcnDelete {this nvar reg} {
     set net $cdata(net)
     $this doLog Close
     foreach x $cdata(users) {
-        $x leave $this
+	$x leave $this
 	$this delTag $x
 	safeUnset ${this}(Op,$x) ${this}(Spk,$x)
     }
@@ -1356,7 +1230,7 @@ proc channel_getAction {this} {
 #
 proc channel_action {this string} {
     switch {} $string {} default {
-	[$this net] qSend PRIVMSG [$this name] ":\001ACTION $string\001"
+	[$this net] q1Send "PRIVMSG [$this name] :\001ACTION $string\001"
 	$this addText @me "* [[$this net] nickname] $string"
 	$this addHist $string
     }
@@ -1477,13 +1351,21 @@ proc channel_flag {this state} {
     }
 }
 #
+proc channel_osTag {this usr nnk} {
+    if {[[$this net] ircIIops]} {
+	if {[$this isSpeaker $usr]} { set nnk +$nnk }
+	if {[$this isOp $usr]} { set nnk @$nnk }
+    }
+    return $nnk
+}
+#
 proc channel_nickChange {this usr nnk} {
     switch [set w [$this window]] {} return
     set uf [$this ufrm]
     set net [$this net]
     $this optText NICK "*** [$usr name] is now known as $nnk"
     if {[$net me $usr]} {
-	catch {$uf.userBtn.$usr configure -text $nnk}
+	catch {$uf.userBtn.$usr configure -text [$this osTag $usr $nnk]}
 	catch {$w.users.menu entryconfigure 3 -label $nnk}
     } {
 	if {[$this isJoined $usr]} {
@@ -1496,11 +1378,11 @@ proc channel_nickChange {this usr nnk} {
 		wsortIns $this $uf.userBtn $nnk $usr
 		$uf.userBtn.$usr configure -fg $fg -bg $bg -font $ft
 	    }
-	}
-	catch {
-	    if {[set x [indexHack $w.users.menu [$usr name] 4]] >=0} {
-		$w.users.menu delete $x
-		sortIns $this $nnk $usr $w.users.menu
+	    catch {
+		if {[set x [indexHack $w.users.menu [$usr name] 4]] >=0} {
+		    $w.users.menu delete $x
+		    sortIns $this $nnk $usr $w.users.menu
+		}
 	    }
 	}
     }
@@ -1532,18 +1414,46 @@ proc sortIns {chan nk usr w} {
     return last
 }
 #
-proc wsortIns {chan win un usr} {
+proc wsortIns {chan win un usr args} {
     set wnk $win.$usr
-    menubutton $wnk -text $un -width [$win cget -width] \
-      -highlightthickness 0 -borderwidth 2 -pady 1 -padx 2
-    $wnk configure -menu [makeUserMenu $chan $wnk.menu $usr]
-    if {![$chan nosort]} {
+    set fn name
+    switch nil $chan {
+	if {[[$usr net] ircIIops]} {
+	    set txt [lindex $args 0]$un
+	} {
+	    set txt $un
+	}
+	set srt 1
+    } default {
+	set txt [$chan osTag $usr $un]
+	set srt [expr {![$chan nosort]}]
 	if {[$chan nocase]} {
 	    set un [string tolower $un]
 	    set fn lname
-	} {
-	    set fn name
 	}
+    }
+    set top text
+    set wd [$win cget -width]
+    switch nil [set fr [$usr fobj]] {} default {
+        switch {} [set fg [$fr image]] {} default {
+           set top image
+	   set img [lindex $fg 0]
+	   set wd {}
+	   switch -glob -- $txt {
+	   @* {
+		    switch {} [set oi [lindex $fg 1]] {} default {set img $oi}
+	       }
+	   +* {
+		    switch {} [set oi [lindex $fg 2]] {} default {set img $oi}
+	       }
+	   }
+	   set txt $img
+	}
+    }
+    menubutton $wnk -$top $txt -highlightthickness 0 -borderwidth 2 -pady 1 -padx 2
+    switch {} $wd {} default { $wnk configure -width $wd }
+    $wnk configure -menu [makeUserMenu $chan $wnk.menu $usr]
+    if {$srt} {
 	set y 1
 	while {![catch {set x [$win window cget 1.$y -window]}]} {
 	    switch {} $x {} default {
@@ -1666,7 +1576,7 @@ proc channel_mode {this vals prefix} {
 			    if {![winfo ismapped [$this ufrm]]} {
 				eval grid [$this ufrm] $cdata(anonpos)
 			    }
-			    $net qSend NAMES :[$this name]
+			    $net q1Send "NAMES :[$this name]"
 			}
 			# set cdata(lcla) $cdata(a)
 			handleOn $net MODE [list [$this name] ${flag}a]
@@ -1730,7 +1640,7 @@ proc channel_mode {this vals prefix} {
 		}
 	    b   {
 		    banProtect $this $prefix $flag $par
-	        }
+		}
 	    }
 	    set nxt [string range $nxt 2 end]
 	    handleOn $net MODE [list [$this name] $flag$m $par]
@@ -1823,24 +1733,6 @@ proc valCmp {this op ln def dc} {
     return $ln
 }
 #
-array set rcSave {
-    all		{open jump quiet history buttons close closetime
-		  timestamp closeleave colour timeformat noshare scrollback}
-    Channel	{draw menu nocase join actionmode nocase nosort}
-    Message	{draw}
-    Notice	{}
-    Chat	{}
-}
-#
-array set rcOpt {
-    all		{foreground background font geometry height width
-		  boldfont messages logfile icon}
-    Channel	{msg ops ban patterns topics key}
-    Message	{}
-    Notice	{}
-    Chat	{}
-}
-#
 proc mncSave {desc this defA} {
     global rcSave rcOpt defaultNet
     set def [getDefault $defA [$this net]]
@@ -1939,7 +1831,7 @@ proc indexHack {w nk start} {
     set x [$w index end]
     set i $start
     while {$i <= $x} {
-	switch -- [$w entrycget $i -label] $nk {return $i}
+	switch -- [$w entrycget $i -label] $nk - @$nk - +$nk - @+$nk {return $i}
 	incr i
     }
     return -1
@@ -1961,7 +1853,7 @@ proc channel_showInfo {this lb txt} {
 }
 #
 proc channel_showFlags {this lb txt} {
-    global zKeyGif zSpkGif zNSpkGif
+    global zKeyGif zSpkGif zNSpkGif zLog
     upvar #0 $this cdata
     if {[winfo exists [set w $cdata(window).cflags]]} {
 	switch {} $txt {
@@ -1972,6 +1864,7 @@ proc channel_showFlags {this lb txt} {
 	    }
 	    switch $lb {
 	    key {$w.key configure -image $zKeyGif}
+	    log {$w.log configure -image $zLog}
 	    mod {
 		    if {![$this operator] && ![$this speaker]} {
 			$w.mod configure -image $zNSpkGif
@@ -1989,24 +1882,24 @@ proc channel_search {this} {
     if {[winfo exists [set w .@srch$this]]} { popup $w ; return }
     toplevel $w -class Zircon
     wm title $w "Search [$this name]"
-    labelEntry 0 $w.search {-text {Search string}} {} "$this doSearch $w"
+    labelEntry 0 $w.search {-text [list [trans {search string}]]} {} "$this doSearch $w"
     $w.search.entry configure -textvariable Search($this,term)
     grid $w.search - -row 0 -sticky ew
     if {![info exists Search($this,case)]} { set Search($this,case) 0 }
-    grid [checkbutton $w.case -text "Case Insensitive" -variable Search($this,case)] \
+    grid [checkbutton $w.case -text [trans {case insensitive}] -variable Search($this,case)] \
       - -row 1 -column 0 -sticky ew
     if {![info exists Search($this,ex)]} { set Search($this,ex) 1 }
-    grid [radiobutton $w.exact -text Exact -variable Search($this,ex) -value 1] \
+    grid [radiobutton $w.exact -text [trans exact] -variable Search($this,ex) -value 1] \
       -row 2 -column 0 -sticky w
-    grid [radiobutton $w.reg -text Regexp -variable Search($this,ex) -value 0] \
+    grid [radiobutton $w.reg -text [trans regexp] -variable Search($this,ex) -value 0] \
       -row 2 -column 1 -sticky w
     if {![info exists Search($this,fwds)]} { set Search($this,fwds) 1 }
-    grid [radiobutton $w.fwds -text Forwards -variable Search($this,fwds) -value 1] \
+    grid [radiobutton $w.fwds -text [trans forwards] -variable Search($this,fwds) -value 1] \
       -row 3 -column 0 -sticky w
-    grid [radiobutton $w.bwds -text Backwards -variable Search($this,fwds) -value 0] \
+    grid [radiobutton $w.bwds -text [trans backwards] -variable Search($this,fwds) -value 0] \
       -row 3 -column 1 -sticky w
     grid [frame $w.line -bg $zircon(sepColor) -borderwidth 2] - -row 4 -sticky ew -pady 4
-    grid [button $w.do -text Search -command "$this doSearch $w"] \
+    grid [button $w.do -text [trans search] -command "$this doSearch $w"] \
       -row 5 -column 0 -sticky ew
     grid [button $w.ok -text [trans dismiss] -command "destroy $w"] \
       -row 5 -column 1 -sticky ew
@@ -2022,23 +1915,6 @@ proc channel_doSearch {this w args} {
     switch {} $res {bell} default {[$this text] see $res}
 }
 #
-proc channel_userSplit {this usr split} {
-    if {[$this isJoined $usr]} {
-	set w [$this window]
-	catch {
-	    if {[set x [indexHack $w.users.menu [$usr name] 3]] >=0} {
-		$w.users.menu entryconfigure $x -state disabled
-	    }
-	}
-	catch {[$this uFrm].userBtn.$usr conf -state disabled}
-	uplevel #0 listincl ${this}(splitusers) $usr
-	$this optText LOST "*** [$usr name] is lost - ($split)"
-    } \
-    elseif {[$this monitor]} {
-        switch {} [$this mwin] {} default {[$this mwin] setState $usr disabled}
-    }
-}
-#
 proc channel_highlight {this} {
     tkwait window [mkEntryBox {} {Text Highlight} \
       {Enter the text you wish highlighted:} \
@@ -2059,13 +1935,13 @@ proc checkJoinTime {this time} {
     if {[catch {set tt [clock scan $time]}]} {
 	tellError {} {JoinAt Error} "Bad time specification in -joinat\
 for channel [$this name] - \"$time\""
-        return 0
+	return 0
     }
     set now [clock seconds]
     if {$now >= $tt} { incr tt [expr {24*60*60}] }
     if {$now >= $tt} {
 	tellError {} {JoinAt Error} "Past time in -joinat for channel [$this name] - \"$time\""
-        return 0
+	return 0
     }
     after [expr {($tt - $now) * 1000}] "$this sendJoin"
     set cdata(joinat) $time
