@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Chat.tcl,v $
-# $Date: 1998/03/03 09:21:27 $
-# $Revision: 1.18.1.42 $
+# $Date: 1998/04/28 13:15:16 $
+# $Revision: 1.18.1.43 $
 #
 package provide zircon 1.18
 #
@@ -138,7 +138,7 @@ proc chat_delete {this} {
 proc chat_leave {this} {
     set chan [$this name]
     if {[askUser LEAVE "Leaving $chan" "Really leave DCC chat with $chan?"]} {
-	$this doLeave {}
+	switch {} [info procs $this] {} default { $this doLeave {} }
     }
 }
 #
