@@ -1,7 +1,7 @@
- #
+#
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/IRC.tcl,v $
-# $Date: 1998/04/28 13:15:21 $
-# $Revision: 1.18.1.52 $
+# $Date: 1998/05/20 09:10:11 $
+# $Revision: 1.18.1.53 $
 #
 package provide zircon 1.18
 #
@@ -47,7 +47,7 @@ proc ircNOTICE {net prefix param pargs} {
     set nkinfo [mungPrefix $net $prefix]
     if {[ignoreSet [lindex $nkinfo 3] notices]} {ditchPrefix $nkinfo ; return}
     set id [find [set chan [lindex $pargs 0]] $net]
-    switch {} [lindex $nkinfo 2] {
+    switch nil [set usr [lindex $nkinfo 0]] {
 	if {[$id active]} {
 	    $id addText {} "-[string range $prefix 1 end]- $param"
 	} {
@@ -57,7 +57,7 @@ proc ircNOTICE {net prefix param pargs} {
 	    }
 	}
     } default {
-	set nk [[set usr [lindex $nkinfo 0]] name]
+	set nk [$usr name]
 	while [regexp "(\[^\001\]*)\001(\[^\001\]*)\001(.*)" $param sub a cp b] {
 	    switch -glob -- $cp {
 	    {ZIRCON Sorry*} { }
@@ -298,10 +298,9 @@ proc ircQUIT {net prefix param pargs} {
 }
 #
 proc ircKICK {net prefix param pargs} {
-    set nkinfo [mungPrefix $net $prefix]
+    set kicker [lindex [mung1Prefix $net $prefix] 0]
     set chan [lindex $pargs 0]
-    set nk [[set who [User :: make $net [lindex $pargs 1]]] name]
-    set kicker [[lindex $nkinfo 0] name]
+    [set who [User :: make $net [set nk [lindex $pargs 1]]]] ref
     set id [Channel :: find $chan $net]
     if {[$net me $who]} {
 	$id optText KICKME "*** You have been kicked off channel $chan by $kicker ($param)"
@@ -320,7 +319,7 @@ proc ircKICK {net prefix param pargs} {
 	$id kickUser $who $prefix 0
    }
    handleOn $net KICK [list $chan $prefix $nk $param]
-   ditchPrefix $nkinfo
+   $who deref
 }
 #
 proc ircINVITE {net prefix param pargs} {
@@ -337,18 +336,17 @@ proc ircINVITE {net prefix param pargs} {
 }
 #
 proc ircKILL {net prefix param pargs} {
-    set nkinfo [mung1Prefix $net $prefix]
-    [set who [User :: make $net [lindex $pargs 0]]] off
-    $who ref
+    set killer [lindex [mung1Prefix $net $prefix] 0]
+    [set who [User :: make $net [lindex $pargs 0]]] ref
+    $who off
     set nk [$who name]
     if {[$net me $who]} {
-	tellInfo $net Killed "You have been killed by [lindex $nkinfo 0] ($param)" KILL
+	tellInfo $net Killed "You have been killed by $killer ($param)" KILL
     } {
 	foreach x {channels notices messages} {
 	    foreach id [$net $x] {
 		if {[$id isJoined $who]} {
-		    $id optText KILL \
-		      "*** $nk has been killed by [lindex $nkinfo 0] ($param)"
+		    $id optText KILL "*** $nk has been killed by $killer ($param)"
 		    $id kickUser $who $prefix 1
 		}
 	    }
