@@ -1,13 +1,10 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Net.tcl,v $
-# $Date: 1998/04/29 11:45:48 $
-# $Revision: 1.18.1.136 $
+# $Date: 1998/05/07 11:01:18 $
+# $Revision: 1.18.1.138 $
 #
 package provide zircon 1.18
 #
-global znetList
-set znetList {}
-#
 proc Net {name args} {
     global XTO defaultNet
     switch $name :: {return [eval Net_[lindex $args 0] [lrange $args 1 end] ]}
@@ -368,20 +365,14 @@ proc net_afterCon {this sock} {
     if {![info exists host]} {set host [info hostname]}
     set server [$srv host]
     set passwd [$srv passwd]
-    foreach ln [$srv script] {
-        if {[catch {puts -nonewline $sock "$ln\n"}]} {
-	    return
-	}
-    }
+    foreach ln [$srv script] { if {[catch {$this q1Send $ln}]} return }
     fileevent $sock readable "ircInput r $sock" 
-    switch {} $passwd {} default {
-        if {[$this qSend PASS :$passwd]} { return }
-    }
-    if {[$this qSend USER $user $host $server :[$this getIrcname]]} {
+    switch {} $passwd {} default { if {[$this q1Send "PASS $passwd"]} return }
+    if {[$this q1Send "USER $user $host $server :[$this getIrcname]"]} {
 	# not connected....
 	return
     }
-    if {[$this qSend NICK $ndata(nickname)]} {
+    if {[$this q1Send "NICK $ndata(nickname)"]} {
 	# connection dropped after USER
 	return
     }
@@ -712,16 +703,16 @@ proc net_setMode {this chan mode args} {
 #
 proc net_WHOIS {this nk args} {
     switch {} $nk return
-    switch {} $args {$this qSend WHOIS :$nk} default {$this qSend WHOIS [lindex $args 0] :$nk}
+    switch {} $args {$this q1Send "WHOIS :$nk"} default {$this q1Send "WHOIS [lindex $args 0] :$nk"}
 }
 #
 proc net_WHOWAS {this nk args} {
     switch {} $nk return
-    switch {} $args {$this qSend WHOWAS :$nk} default {$this qSend WHOWAS $nk :[lindex $args 0]}
+    switch {} $args {$this q1Send "WHOWAS :$nk"} default {$this q1Send "WHOWAS $nk :[lindex $args 0]"}
 }
 #
 proc net_INFO {this args} {
-    switch {} $args {$this q1Send INFO} default {$this qSend INFO :[lindex $args 0]}
+    switch {} $args {$this q1Send INFO} default {$this q1Send "INFO :[lindex $args 0]"}
 }
 #
 proc net_ISON {this} {
@@ -734,92 +725,93 @@ proc net_ISON {this} {
 #
 proc net_SQUIT {this srv reason} { 
     switch {} $reason { set reason {No reason given} }
-    $this qSend SQUIT $srv :$reason
+    $this q1Send "SQUIT $srv :$reason"
 }
 #
-proc net_TIME {this nk} { $this qSend TIME :$nk }
+proc net_TIME {this nk} { $this q1Send "TIME :$nk" }
 #
-proc net_PRIVMSG {this where what} { $this qSend PRIVMSG $where :$what }
+proc net_PRIVMSG {this where what} { $this q1Send "PRIVMSG $where :$what" }
 #
 proc net_NOTICE {this where what} {
     switch {} $where return
     switch {} $what return
-    $this qSend NOTICE $where :$what
+    $this q1Send "NOTICE $where :$what"
 }
 #
 proc net_INVITE {this who where} {
     switch {} $who return
     switch {} $where return
-    $this qSend INVITE $who :$where
+    $this q1Send "INVITE $who :$where"
 }
 #
-proc net_KILL {this who why} { $this qSend KILL $who :$why }
+proc net_KILL {this who why} { $this q1Send "KILL $who :$why" }
 #
 proc net_KICK {this where who args} {
-    switch {} $args {$this qSend KICK $where :$who} default {$this qSend KICK $where $who :[lindex $args 0]}
+    switch {} $args {$this q1Send "KICK $where :$who"} \
+      default {$this q1Send "KICK $where $who :[lindex $args 0]"}
 }
 #
-proc net_STATS {this p1 p2} { $this qSend STATS $p1 :$p2 }
+proc net_STATS {this p1 p2} { $this q1Send "STATS $p1 :$p2" }
 #
-proc net_USERHOST {this nk} { $this qSend USERHOST :$nk }
+proc net_USERHOST {this nk} { $this q1Send "USERHOST :$nk" }
 #
 proc net_NICK {this name} {
     if {[$this startup]} { $this setNickname $name }
-    $this qSend NICK :$name
+    $this q1Send "NICK :$name"
 }
 proc net_MODE {this who mode args} {
     switch [llength $args] {
-    0 {	$this qSend MODE $who :$mode }
-    1 {	$this qSend MODE $who $mode :[lindex $args 0] }
+    0 {	$this q1Send "MODE $who :$mode" }
+    1 {	$this q1Send "MODE $who $mode :[lindex $args 0]" }
     default { error "MODE Called with too many parameters" }
     }
 }
 #
 proc net_CONNECT {this srv port remote} {
     switch {} $srv return
-    $this qSend CONNECT $srv $port :$remote
+    $this q1Send "CONNECT $srv $port :$remote"
 }
 #
 proc net_LINKS {this srv mask} {
     switch {} $srv {
-	switch {} $mask {$this q1Send LINKS} default {$this qSend LINKS [$this host] :$mask}
+	switch {} $mask {$this q1Send LINKS} default {$this q1Send "LINKS [$this host] :$mask"}
     } default {
-	switch {} $mask {$this qSend LINKS :$srv} default {$this qSend LINKS $srv :$mask}
+	switch {} $mask {$this q1Send "LINKS :$srv"} default {$this q1Send "LINKS $srv :$mask"}
     }
 }
 #
 proc net_nsend {this cmd par} {
-    switch {} $par {$this q1Send $cmd} default {$this qSend $cmd :$par}
+    switch {} $par {$this q1Send $cmd} default {$this q1Send "$cmd :$par"}
 }
 #
 proc net_AWAY {this args} {
-    switch {} $args {$this q1Send AWAY} default {$this qSend AWAY :[join $args]}
+    switch {} $args {$this q1Send AWAY} default {$this q1Send "AWAY :[join $args]"}
 }
 #
 proc net_TOPIC {this chan args} {
-    switch {} $args {$this qSend TOPIC :$chan} default {$this qSend TOPIC $chan :[lindex $args 0]}
+    switch {} $args {$this q1Send "TOPIC :$chan"} default {$this q1Send "TOPIC $chan :[lindex $args 0]"}
 }
 #
 proc net_CTCP {this cmd nk str} {
     switch {} $str {
-	$this qSend PRIVMSG $nk ":\001$cmd\001"
+	$this q1Send "PRIVMSG $nk :\001$cmd\001"
     } default {
-	$this qSend PRIVMSG $nk ":\001$cmd $str\001"
+	$this q1Send "PRIVMSG $nk :\001$cmd $str\001"
     }
 }
 #
 proc net_PART {this chan args} {
-    switch {} $args {$this qSend PART :$chan} default {$this qSend PART $chan :[lindex $args 0]}
+    switch {} $args {$this q1Send "PART :$chan"} default {$this q1Send "PART $chan :[lindex $args 0]"}
 }
 #
 proc net_OPER {this nk str} {
     switch {} $str return
-    $this qSend OPER  $nk :$str
+    $this q1Send "OPER  $nk :$str"
 }
 #
-proc net_NAMES {this chan} { $this qSend NAMES :$chan }
+proc net_NAMES {this chan} { $this q1Send "NAMES :$chan" }
 #
-proc net_PING {this srv} { $this qSend PING :$srv}
+proc net_PING {this srv} { $this q1Send "PING :$srv"}
 #
 proc net_error {this prefix param pargs} {
     set hst [$this host]
@@ -873,14 +865,14 @@ proc net_servlist {this} {
 proc net_SQUERY {this sv qr} {
     switch {} $sv return
     switch {} $qr return
-    $this qSend SQUERY "$sv :$qr"
+    $this q1Send "SQUERY $sv :$qr"
 }
 #
 #
 proc net_SERVLIST {this n t} {
     switch {} $n return
     switch {} $t return
-    $this qSend SERVLIST "$n :$t"
+    $this q1Send "SERVLIST $n :$t"
 }
 #
 proc net_clearMsgs {this usrs} {
