@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Notice.tcl,v $
-# $Date: 1998/03/03 09:21:36 $
-# $Revision: 1.18.1.34 $
+# $Date: 1998/04/28 13:15:29 $
+# $Revision: 1.18.1.35 $
 #
 package provide zircon 1.18
 #
@@ -130,7 +130,7 @@ proc notice_save {this desc} { }
 proc notice_leave {this} {
     set chan [$this name]
     if {[askUser LEAVE "Leaving Notice $chan" "Really close notice from $chan?"]} {
-	$this delete
+	switch {} [info procs $this] {} default { $this delete }
     }
 }
 #
