@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/On.tcl,v $
-# $Date: 1998/02/10 10:48:38 $
-# $Revision: 1.18.1.12 $
+# $Date: 1998/04/21 15:17:28 $
+# $Revision: 1.18.1.14 $
 #
 package provide zircon 1.18
 #
@@ -10,6 +10,11 @@ package provide zircon 1.18
 proc on {action pattern code} {
     global currentNet
     upvar #0 OnCode$currentNet OnCode
+    switch [set action [string toupper $action]] \
+      NICK	{ set action NICKNAME } \
+      CONNECT	{ set action STARTUP } \
+      NOTIFY_SIGNON { set action ISON } \
+      NOTIFY_SIGNOFF { set action ISOFF }
     set pat {}
     foreach p $pattern { lappend pat [string tolower $p] }
     lappend OnCode([string toupper $action]) [list $pat $code]
