@@ -1,11 +1,11 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Sound.tcl,v $
-# $Date: 1998/04/14 12:21:58 $
-# $Revision: 1.18.1.10 $
+# $Date: 1998/04/23 08:59:13 $
+# $Revision: 1.18.1.12 $
 #
 package provide zircon 1.18
 #
-proc handleSound {net usr fl} {
+proc handleSound {net usr fl chan prefix} {
     global zircon
     switch {} [$net wavplayer] {} default {
 	switch [file pathtype $fl] absolute {
@@ -29,6 +29,9 @@ proc handleSound {net usr fl} {
 		return
 	    }
 	}
+	switch {} $chan {} default {
+	    handleOn $net NOSOUND [list $fl $chan $prefix]
+	}
     }
 }
 #
@@ -36,7 +39,7 @@ proc doSendSound {net nk fl} {
     switch {} $fl return
     set tfl [file tail [file rootname $fl]]
     $net CTCP SOUND $nk "$tfl <$tfl>"
-    handleSound $net [$net nickname] $fl
+    handleSound $net [$net nickname] $fl {} {}
 }
 #
 proc addSoundMenu {net menu chid} {
