@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/confTab.tcl,v $
-# $Date: 1998/05/07 11:01:28 $
-# $Revision: 1.18.1.15 $
+# $Date: 1998/06/07 19:21:26 $
+# $Revision: 1.18.1.16 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -72,7 +72,8 @@ proc drawTabs {net} {
 }
 #
 proc tabShow {net pane} {
-    global t option pref lastConf
+    global t option pref lastConf tablock
+    if {[info exists tablock($net)]} return
     set w .@conf$net
     $w.page itemconfigure tab -fill [$w.page cget -selectbackground]
     $w.page itemconfigure tab-$pane -fill [$w.page cget -background]
@@ -133,14 +134,14 @@ proc confdismiss {net win} {
     foreach x [$net confChange] {
         confrevclean $net $x 
     }
-    safeUnset confI$net
+    safeUnset confI$net tablock($net)
 }
 #
 proc confrevert {net win} {
     global lastConf
     confrevclean $net $lastConf($net)
-    tabShow $net $lastConf($net)
     confClean $net
+    tabShow $net $lastConf($net)
 }
 #
 proc confsave {net win} {
@@ -159,37 +160,41 @@ proc confapply {net win} {
 }
 #
 proc confDirty {net} {
-    global lastConf
+    global lastConf tablock
     $net configure +confChange $lastConf($net)
     set win .@conf$net
     foreach bt {revert apply save} { $win.btn.$bt configure -state normal }
+    catch {unset tablock($net)}
 }
 #
 proc confCleaner {net} {
-    global lastConf
+    global lastConf tablock
     $net configure -confChange [listremove [$net confChange] $lastConf($net)]
     set win .@conf$net
     foreach bt {apply} { $win.btn.$bt configure -state disabled }
+    catch {unset tablock($net)}
 }
 #
 proc confClean {net} {
-    global lastConf
+    global lastConf tablock
     $net configure -confChange [listremove [$net confChange] $lastConf($net)]
     set win .@conf$net
     foreach bt {revert apply save} { $win.btn.$bt configure -state disabled }
+    catch {unset tablock($net)}
 }
 #
 proc confDABtns {net args} {
-    global cbwstate
+    global cbwstate tablock
     set win .@conf$net
     foreach bt {revert apply save dismiss} {
 	set cbwstate($net,$bt) [$win.btn.$bt cget -state]
 	$win.btn.$bt configure -state disabled
     }
+    set tablock($net) 1
 }
 #
 proc confRABtns {net args} {
-    global cbwstate
+    global cbwstate tablock
     set win .@conf$net
     foreach bt {revert apply save dismiss} {
 	switch {} [$net confChange] {set st $cbwstate($net,$bt) } default {
@@ -198,4 +203,5 @@ proc confRABtns {net args} {
 	$win.btn.$bt configure -state $st
 	catch {unset cbwstate($net,$bt)}
     }
+    catch {unset tablock($net)}
 }
