@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/misc2.tcl,v $
-# $Date: 1998/04/28 13:15:34 $
-# $Revision: 1.18.1.33 $
+# $Date: 1998/06/06 10:33:21 $
+# $Revision: 1.18.1.37 $
 #
 #
 package provide zircon 1.18
@@ -9,18 +9,24 @@ package provide zircon 1.18
 proc net_doMisc2 {this chid win} {
     set line [$win get]
     $win delete 0 end
+    if {![doircII $this $chid $line]} {
+        $chid send $line
+    }
+}
+#
+proc doircII {net chid line} {
     if {[regexp {^(/[a-zA-Z]+)( (.*))?$} $line dummy pr r1 rest]} {
-	set pr [string toupper $pr]
-	switch {} [info procs $pr] {
+	set upr [string toupper $pr]
+	$chid addHist $line
+	switch {} [info procs ircII_$upr] {
 	    $chid addText @me "!> \"$pr\" does not exist or is unsupported.\a"
 	} default {
 	    $chid addText @me "!> $line"
-	    $pr $this $chid [string trim $rest]
+	    ircII_$upr $net $chid [string trim $rest]
 	}
-	$chid addHist $line
-	return
+	return 1
     }
-    $chid send $line
+    return 0
 }
 #
 proc deCap {str} {
@@ -37,26 +43,26 @@ proc colonLast {arg} {
     }
 }
 #
-proc /ABORT {net chid arg} { exit }
+proc ircII_/ABORT {net chid arg} { exit }
 #
-proc /ADMIN {net chid arg} { $net nsend ADMIN [lindex $arg 0]}
+proc ircII_/ADMIN {net chid arg} { $net nsend ADMIN [lindex $arg 0]}
 #
-proc /ALIAS {net chid arg} { sillyPerson $net }
+proc ircII_/ALIAS {net chid arg} { sillyPerson $net }
 #
-proc /ASSIGN {net chid arg} {
+proc ircII_/ASSIGN {net chid arg} {
     upvar #0 uVars$net uvars
     set uvars([lindex $arg 0]) [lindex $arg 1]
 }
 #
-proc /AWAY {net chid arg} { $net AWAY $arg }
+proc ircII_/AWAY {net chid arg} { $net AWAY $arg }
 #
-proc /BEEP {args} { bell }
+proc ircII_/BEEP {args} { bell }
 #
-proc /BIND {net chid arg} { sillyPerson $net }
+proc ircII_/BIND {net chid arg} { sillyPerson $net }
 #
-proc /BYE {net chid arg} { $net doQuit [lindex $arg 0]}
+proc ircII_/BYE {net chid arg} { $net doQuit [lindex $arg 0]}
 #
-proc /CD {net chid arg} {
+proc ircII_/CD {net chid arg} {
     switch {} $arg {
 	tellInfo $net {Working Directory} [pwd]
     } default {
@@ -64,17 +70,17 @@ proc /CD {net chid arg} {
     }
 }
 #
-proc /CHANNEL {net chid arg} { channelJoin $net [lindex $arg 0] }
+proc ircII_/CHANNEL {net chid arg} { channelJoin $net [lindex $arg 0] }
 #
-proc /CLEAR {net chid arg} { $chid clear 1 }
+proc ircII_/CLEAR {net chid arg} { $chid clear 1 }
 #
-proc /COMMENT {net chid arg} { }
+proc ircII_/COMMENT {net chid arg} { }
 #
-proc /CONNECT {net chid arg} {
+proc ircII_/CONNECT {net chid arg} {
     $net CONNECT [lindex $arg 0] [lindex $arg 1] [lindex $arg 3]
 }
 #
-proc /CTCP {net chid arg} {
+proc ircII_/CTCP {net chid arg} {
     set nk [lindex $arg 0]
     switch * $nk {set nk [$chid name]}
     switch [set cmd [string toupper [lindex $arg 1]]] {
@@ -84,15 +90,13 @@ proc /CTCP {net chid arg} {
     SOUND -
     ACTION -
     ECHO {$net CTCP $cmd $nk $arg }
-    default {
-	    $net CTCP $cmd $nk {}
-	}
+    default { $net CTCP $cmd $nk [lrange $arg 2 end] }
     }
 }
 #
-proc /DATE {net chid arg} { $net TIME $arg }
+proc ircII_/DATE {net chid arg} { $net TIME $arg }
 #
-proc /DCC {net chid arg} {
+proc ircII_/DCC {net chid arg} {
     set op [string toupper [lindex $arg 0]]
     switch -- $op {
     SEND {
@@ -131,38 +135,38 @@ proc /DCC {net chid arg} {
     }
 }
 #
-proc /DEOP {net chid arg} { $net deIRCOp }
+proc ircII_/DEOP {net chid arg} { $net deIRCOp }
 #
-proc /DESCRIBE {net chid arg} {
+proc ircII_/DESCRIBE {net chid arg} {
     set chan [lindex $arg 0]
     if {[string compare nil [set ch [Channel :: find $chan $net]]] ||
 	[string compare nil [set ch [Message :: find $chan $net]]]} {
 	$ch action [lrange $arg 1 end]
     } {
-	$net qSend PRIVMSG $chan ":\001ACTION [lrange $arg 1 end]\001"
+	$net q1Send "PRIVMSG $chan :\001ACTION [lrange $arg 1 end]\001"
     }
 }
 #
-proc /DIE {net chid arg} { sillyPerson $net }
+proc ircII_/DIE {net chid arg} { sillyPerson $net }
 #
-proc /DIGRAPH {net chid arg} { sillyPerson $net }
+proc ircII_/DIGRAPH {net chid arg} { sillyPerson $net }
 #
-proc /DMSG {net chid arg} {
+proc ircII_/DMSG {net chid arg} {
     switch nil [set cht [Chat :: find [lindex $arg 0] $net]] {
 	tellError $net Error {No such DCC chat  connection}
     } default {$cht send [lrange $arg 1 end]}
 }
 #
-proc /DQUERY {net chid arg} {
+proc ircII_/DQUERY {net chid arg} {
     set usr [User :: make $net $arg]
     set cht [Chat :: make $net [$usr name]]
     $cht show
     if {![$cht isJoined $usr]} { $cht addUser $usr 0 0 }
 }
 #
-proc /ECHO {net chid arg} { $net inform $arg }
+proc ircII_/ECHO {net chid arg} { $net inform $arg }
 #
-proc /ENCRYPT {net chid arg} {
+proc ircII_/ENCRYPT {net chid arg} {
     set nk [lindex $arg 0]
     if {[string match {[#&]} $nk]} {
 	set chid [Channel :: make $net $nk]
@@ -172,23 +176,23 @@ proc /ENCRYPT {net chid arg} {
     $chid configure -key [lindex $arg 1]
 }
 #
-proc /EVAL {net chid arg} { sillyPerson $net }
+proc ircII_/EVAL {net chid arg} { sillyPerson $net }
 #
-proc /EXEC {net chid arg} { runCmd $net $chid $arg }
+proc ircII_/EXEC {net chid arg} { runCmd $net $chid $arg }
 #
-proc /EXIT {net chid arg} { $net doQuit [lindex $arg 0]}
+proc ircII_/EXIT {net chid arg} { $net doQuit [lindex $arg 0]}
 #
-proc /FLUSH {net chid arg} { sillyPerson $net }
+proc ircII_/FLUSH {net chid arg} { sillyPerson $net }
 #
-proc /FOREACH {net chid arg} { sillyPerson $net }
+proc ircII_/FOREACH {net chid arg} { sillyPerson $net }
 #
-proc /HELP {net chid arg} { sillyPerson $net }
+proc ircII_/HELP {net chid arg} { sillyPerson $net }
 #
-proc /HISTORY {net chid arg} { sillyPerson $net }
+proc ircII_/HISTORY {net chid arg} { sillyPerson $net }
 #
-proc /HOOK {net chid arg} { sillyPerson $net }
+proc ircII_/HOOK {net chid arg} { sillyPerson $net }
 #
-proc /IF {net chid arg} { sillyPerson $net }
+proc ircII_/IF {net chid arg} { sillyPerson $net }
 #
 proc flgAdd {lst flag op} {
     switch -- $flag {
@@ -200,7 +204,7 @@ proc flgAdd {lst flag op} {
     return $lst
 }
 #
-proc /IGNORE {net chid arg} {
+proc ircII_/IGNORE {net chid arg} {
     global zircon
     if {[string match *@* [set nk [lindex $arg 0]]]} {
     	set nk *!$nk
@@ -227,33 +231,33 @@ proc /IGNORE {net chid arg} {
     $net configure +confChange Ignores
 }
 #
-proc /INFO {net chid arg} { $net INFO $arg }
+proc ircII_/INFO {net chid arg} { $net INFO $arg }
 #
-proc /INPUT {net chid arg} { sillyPerson $net }
+proc ircII_/INPUT {net chid arg} { sillyPerson $net }
 #
-proc /INVITE {net chid arg} {
+proc ircII_/INVITE {net chid arg} {
     set nk [lindex $arg 0]
     foreach x [lrange $arg 1 end] { $net INVITE $nk $x }
 }
 
 #
-proc /JOIN {net chid arg} { channelJoin $net $arg }
+proc ircII_/JOIN {net chid arg} { channelJoin $net $arg }
 #
-proc /KICK {net chid arg} {
+proc ircII_/KICK {net chid arg} {
     set chn [lindex $arg 0]
     switch * $chn {set chn [$chid name]}
     $net KICK $chn [lindex $arg 1] [lrange $arg 2 end]
 }
 #
-proc /KILL {net chid arg} {$net KILL [lindex $arg 0] [lrange $arg 1 end]}
+proc ircII_/KILL {net chid arg} {$net KILL [lindex $arg 0] [lrange $arg 1 end]}
 #
-proc /LASTLOG {net chid arg} { sillyPerson $net }
+proc ircII_/LASTLOG {net chid arg} { sillyPerson $net }
 #
-proc /LEAVE {net chid arg} { /PART $net $chid $arg }
+proc ircII_/LEAVE {net chid arg} { ircII_/PART $net $chid $arg }
 #
-proc /LINKS {net chid arg} { $net LINKS [lindex $arg 0] [lindex $arg 1] }
+proc ircII_/LINKS {net chid arg} { $net LINKS [lindex $arg 0] [lindex $arg 1] }
 #
-proc /LIST {net chid arg} { 
+proc ircII_/LIST {net chid arg} { 
     set chan {}
     while {$arg != {}} {
 	set inc 1
@@ -276,43 +280,43 @@ proc /LIST {net chid arg} {
     $net channelList $chan
 }
 #
-proc /LOAD {net chid arg} {  sillyPerson $net }
+proc ircII_/LOAD {net chid arg} {  sillyPerson $net }
 #
-proc /LUSERS {net chid arg} {$net send LUSERS [lindex $arg 0] [lindex $arg 1]}
+proc ircII_/LUSERS {net chid arg} {$net send LUSERS [lindex $arg 0] [lindex $arg 1]}
 #
-proc /ME {net chid arg} { $chid action $arg }
+proc ircII_/ME {net chid arg} { $chid action $arg }
 #
-proc /MLOAD {net chid arg} { sillyPerson $net }
+proc ircII_/MLOAD {net chid arg} { sillyPerson $net }
 #
-proc /MODE {net chid arg} {
+proc ircII_/MODE {net chid arg} {
     set foo [deCap $arg]
     set chn [lindex $foo 0]
     switch * $chn {set chn [$chid name]}
     switch {} [set rest [colonLast [lindex $foo 1]]] {
-	$net qSend MODE :$chn
+	$net q1Send "MODE :$chn"
     } default {
-	$net qSend MODE $chn $rest
+	$net q1Send "MODE $chn $rest"
     }
 }
 #
-proc /MOTD {net chid arg} { $net send MOTD $arg }
+proc ircII_/MOTD {net chid arg} { $net send MOTD $arg }
 #
-proc /MSG {net chid arg} {
+proc ircII_/MSG {net chid arg} {
     set foo [deCap $arg]
-    $net qSend PRIVMSG [lindex $foo 0] :[lindex $foo 1]
+    $net q1Send "PRIVMSG [lindex $foo 0] :[lindex $foo 1]"
 }
 #
-proc /NAMES {net chid arg} { $net NAMES $arg }
+proc ircII_/NAMES {net chid arg} { $net NAMES $arg }
 #
-proc /NICK {net chid arg} { $net NICK $arg }
+proc ircII_/NICK {net chid arg} { $net NICK $arg }
 #
-proc /NOTE {net chid arg} { sillyPerson $net }
+proc ircII_/NOTE {net chid arg} { sillyPerson $net }
 #
-proc /NOTICE {net chid arg} {
+proc ircII_/NOTICE {net chid arg} {
     $net NOTICE [lindex $arg 0] [lrange $arg 1 end]
 }
 #
-proc /NOTIFY {net chid arg} { 
+proc ircII_/NOTIFY {net chid arg} { 
     switch -- $arg {} {
 	set here {}
 	set nothere {}
@@ -354,13 +358,13 @@ proc /NOTIFY {net chid arg} {
     }
 }
 #
-proc /ON {net chid arg} { sillyPerson $net }
+proc ircII_/ON {net chid arg} { sillyPerson $net }
 #
-proc /OPER {net chid arg} {$net OPER [lindex $arg 0] [lindex $arg 1]}
+proc ircII_/OPER {net chid arg} {$net OPER [lindex $arg 0] [lindex $arg 1]}
 #
-proc /PARSEKEY {net chid arg} { sillyPerson $net }
+proc ircII_/PARSEKEY {net chid arg} { sillyPerson $net }
 #
-proc /PART {net chid arg} {
+proc ircII_/PART {net chid arg} {
     switch -- $arg {} - * {
 	$chid doLeave {}
     } default {
@@ -370,36 +374,36 @@ proc /PART {net chid arg} {
     }
 }
 #
-proc /PING {net chid arg} { foreach nk $arg { doCtcp $net PING $nk } }
+proc ircII_/PING {net chid arg} { foreach nk $arg { doCtcp $net PING $nk } }
 #
-proc /QUERY {net chid arg} {
+proc ircII_/QUERY {net chid arg} {
     set usr [User :: make $net $arg]
     set msg [Message :: make $net [$usr name]]
     $msg show
     if {![$msg isJoined $usr]} { $msg addUser $usr 0 0 }
 }
 #
-proc /QUIT {net chid arg} { $net doQuit $arg }
+proc ircII_/QUIT {net chid arg} { $net doQuit $arg }
 #
-proc /QUOTE {net chid arg} {  $net sendRaw $arg }
+proc ircII_/QUOTE {net chid arg} {  $net sendRaw $arg }
 #
-proc /RAW {net chid arg} {  $net sendRaw $arg }
+proc ircII_/RAW {net chid arg} {  $net sendRaw $arg }
 #
-proc /REDIRECT {net chid arg} { sillyPerson $net }
+proc ircII_/REDIRECT {net chid arg} { sillyPerson $net }
 #
-proc /REHASH {net chid arg} { $net q1Send REHASH }
+proc ircII_/REHASH {net chid arg} { $net q1Send REHASH }
 #
-proc /RESTART {net chid arg} { $net q1Send RESTART }
+proc ircII_/RESTART {net chid arg} { $net q1Send RESTART }
 #
-proc /SAVE {net chid arg} { saverc $net }
+proc ircII_/SAVE {net chid arg} { saverc $net }
 #
-proc /SAY {net chid arg} { $chid send $arg }
+proc ircII_/SAY {net chid arg} { $chid send $arg }
 #
-proc /SEND {net chid arg} { $chid send $arg }
+proc ircII_/SEND {net chid arg} { $chid send $arg }
 #
-proc /SENDLINE {net chid arg} { sillyPerson $net }
+proc ircII_/SENDLINE {net chid arg} { sillyPerson $net }
 #
-proc /SERVER {net chid arg} {
+proc ircII_/SERVER {net chid arg} {
     set sv [Server :: make $net [lindex $arg 0]]
     if {[set port [lindex $arg 1]] != {}} { $sv configure -port $port }
     $net changeServer $sv
@@ -413,39 +417,80 @@ proc setBool {chan var val} {
     TOGGLE	{ set cdata($var) [expr {!$cdata($var)}] }
 }
 #
-proc /SET {net chid arg} { 
+proc ircII_/SET {net chid arg} { 
     switch [string toupper [lindex $arg 0]] \
     BEEP { setBool $chid quiet [lindex $arg 1] } \
     BEEP_MAX { $net configure -beeplimit [lindex $arg 1] } \
     CHANNEL_NAME_WIDTH { $net configure -namewidth [lindex $arg 1] }
 }
 #
-proc /SIGNOFF {net chid arg} { $net doQuit $arg }
+proc ircII_/SIGNOFF {net chid arg} { $net doQuit $arg }
 #
-proc /SLEEP {net chid arg} { after [lindex $arg 0] }
+proc ircII_/SLEEP {net chid arg} { after [lindex $arg 0] }
 #
-proc /SQUIT {net chid arg} {
+proc ircII_/SQUIT {net chid arg} {
     set foo [deCap $arg]
     $net SQUIT [lindex $foo 0] [lindex $foo 1]
 }
 #
-proc /STATS {net chid arg} { $net STATS [lindex $arg 0] [lindex $arg 1] }
+proc ircII_/STATS {net chid arg} { $net STATS [lindex $arg 0] [lindex $arg 1] }
 #
-proc /SUMMON {net chid arg} { $net qSend SUMMON [colonLast $arg] }
+proc ircII_/SUMMON {net chid arg} { $net q1Send "SUMMON [colonLast $arg]" }
 #
-proc /TIME {net chid arg} { $net qSend TIME [colonLast $arg] }
+proc ircII_/TIME {net chid arg} { $net q1Send "TIME [colonLast $arg]" }
 #
-proc /TIMER {net chid arg} { }
+proc ircII_/TIMER {net chid arg} {
+    upvar #0 timers$net timers
+    switch {} $arg {
+        foreach x [lsort [array names timers]] {
+	    if {[catch {set info [after info $timers($x)]}]} {
+	        unset timers($x)
+	    } {
+	        $net inform "Timer $x : [lindex [lindex $info 0] 2]"
+	    }
+	}
+	return
+    }
+    set refnum {}
+    switch -- [lindex $arg 0] {
+    -refnum {
+            set refnum [lindex $arg 1]
+	    if {[info exists timers($refnum)]} {
+	        $net inform "Timer $refnum already exists."
+		return
+	    }
+	    set arg [lrange $arg 2 end]
+        }
+    -delete {
+	    set refnum [lindex $arg 1]
+	    if {[info exists timers($refnum)]} {
+	    	after cancel $timers($refnum)
+		$net inform "Timer $refnum deleted."
+		unset timers($refnum)
+	    } {
+	        $net inform "No such timer as $refnum"
+	    }
+	    return
+	}
+    }
+    switch {} $refnum {
+        set refnum [$net timercount]
+	$net configure -timercount [expr {$refnum + 1}]
+    }
+    set timers($refnum) [after [expr {[lindex $arg 0] * 1000}] \
+        "$net eval [list [lrange $arg 1 end]] ; unset timers${net}($refnum)"]
+    $net inform "Timer $refnum recorded."
+}
 #
-proc /TOPIC {net chid arg} { $chid configure -topic $arg}
+proc ircII_/TOPIC {net chid arg} { $chid configure -topic $arg}
 #
-proc /TRACE {net chid arg} { $net nsend TRACE $arg }
+proc ircII_/TRACE {net chid arg} { $net nsend TRACE $arg }
 #
-proc /TYPE {net chid arg} { 
+proc ircII_/TYPE {net chid arg} { 
     [$chid window].cmd.entry insert insert $arg
 }
 #
-proc /USERHOST {net chid arg} {
+proc ircII_/USERHOST {net chid arg} {
     foreach x $arg {
 	if {[string compare -cmd $x]} {$net USERHOST $x} {
 	    sillyPerson $net
@@ -454,29 +499,29 @@ proc /USERHOST {net chid arg} {
     }
 }
 #
-proc /USERS {net chid arg} { $net send USERS $arg }
+proc ircII_/USERS {net chid arg} { $net send USERS $arg }
 #
-proc /VERSION {net chid arg} { $net send VERSION $arg }
+proc ircII_/VERSION {net chid arg} { $net send VERSION $arg }
 #
-proc /WAIT {net chid arg} { sillyPerson $net }
+proc ircII_/WAIT {net chid arg} { sillyPerson $net }
 #
-proc /WALLOPS {net chid arg} { sillyPerson $net }
+proc ircII_/WALLOPS {net chid arg} { sillyPerson $net }
 #
-proc /WHICH {net chid arg} { sillyPerson $net }
+proc ircII_/WHICH {net chid arg} { sillyPerson $net }
 #
-proc /WHILE {net chid arg} { sillyPerson $net }
+proc ircII_/WHILE {net chid arg} { sillyPerson $net }
 #
-proc /WHO {net chid arg} { $net qSend WHO [colonLast $arg] }
+proc ircII_/WHO {net chid arg} { $net q1Send "WHO [colonLast $arg]" }
 #
-proc /WHOIS {net chid arg} { $net qSend WHOIS [colonLast $arg] }
+proc ircII_/WHOIS {net chid arg} { $net q1Send "WHOIS [colonLast $arg]" }
 #
-proc /WHOWAS {net chid arg} { $net qSend WHOWAS [colonLast $arg] }
+proc ircII_/WHOWAS {net chid arg} { $net q1Send "WHOWAS [colonLast $arg]" }
 #
-proc /WINDOW {net chid arg} { sillyPerson $net}
+proc ircII_/WINDOW {net chid arg} { sillyPerson $net}
 #
-proc /XECHO {net chid arg} { sillyPerson $net}
+proc ircII_/XECHO {net chid arg} { sillyPerson $net}
 #
-proc /XTYPE {net chid arg} { sillyPerson $net}
+proc ircII_/XTYPE {net chid arg} { sillyPerson $net}
 #
 proc sillyPerson {net} {
     bell
