@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/userCmds.tcl,v $
-# $Date: 1997/05/16 09:42:50 $
-# $Revision: 1.18.1.11 $
+# $Date: 1998/04/30 13:17:58 $
+# $Revision: 1.18.1.12 $
 #
 package provide zircon 1.18
 #
@@ -72,7 +72,7 @@ proc userWhowas {net} {
 proc doUMode {net nk mode} {
     if {![string match {} $nk] && [string match {[+-]*} mode]} {
 	$net configure -lastuser $Nk
-	$net qSend MODE $nk :$mode
+	$net q1Send "MODE $nk :$mode"
     }
 }
 #
@@ -103,7 +103,7 @@ proc userCmd {net cmd args} {
 proc uSend {net cmd nk} {
     switch {} $nk return
     $net configure -lastuser $nk
-    $net qSend $cmd :$nk
+    $net q1Send "$cmd :$nk"
 }
 
 
