@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/plugins/Dcc/RCS/dcc.tcl,v $
-# $Date: 1998/04/27 15:38:15 $
-# $Revision: 1.18.1.53 $
+# $Date: 1998/05/21 13:31:42 $
+# $Revision: 1.18.1.56 $
 #
 package provide Dcc 1.18
 #
@@ -89,7 +89,7 @@ proc doGetDCC {net wh usr addr port leng posn args} {
 	set file [file join [file dirname $file] [file tail $file]]
 	set sk [socket -async $host $port]
 	fconfigure $sk -blocking 1
-	fileevent $sk writable "startGet $sk $net $file $usr $leng $posn"
+	fileevent $sk writable "startGet $sk $net [list $file] $usr $leng $posn"
     }
     return 1
 }
@@ -160,7 +160,7 @@ proc handleDCC {net usr param prefix} {
     set fln [lindex $pars 1]
     set addr [lindex $pars 2]
     set port [lindex $pars 3]
-    switch -exact -- [lindex $pars 0] {
+    switch -exact -- [string toupper [lindex $pars 0]] {
     RESUME { handleResume $net $usr $fln $addr $port }
     ACCEPT { handleAccept $net $usr $fln $addr $port }
     SEND {
@@ -276,14 +276,6 @@ proc doTitle {grd w sub ttl} {
     if {$grd > 1} { openFrame $w $sub } { closeFrame $w $sub }
 }
 #
-array set tls {
-    coff	{Chat Offers}
-    achat	{Active Chats}
-    fOffer	{File Offers}
-    fSend	{Active File Sends}
-    fGet	{Active File Gets}
-}
-#
 proc buildDCCList {net args} {
     global tls
     if {[winfo exists [set w .@dls$net]]} {
